# coding: utf-8

"""
    Segnivo Developer API

    **API Version**: 1.7  **Date**: 9th July, 2024  ## 📄 Getting Started  This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.  Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.  The API must not be abused and should be used within acceptable limits.  To start using this API, you will need not create or access an existing Segnivo account to obtain your API key ([retrievable from your account settings](https://messaging.segnivo.com/account/api)).  - You must use a valid API Key to send requests to the API endpoints.      - The API only responds to HTTPS-secured communications. Any requests sent via HTTP return an HTTP 301 redirect to the corresponding HTTPS resources.      - The API returns request responses in JSON format. When an API request returns an error, it is sent in the JSON response as an error key or with details in the message key.       ### 🔖 **Need some help?**  In case you have questions or need clarity with interacting with some endpoints feel free to create a support ticket on your account or you can send an email ([<i>developers@segnivo.com</i>](https://mailto:developers@segnivo.com)) directly and we would be happy to help.  ---  ## Authentication  As noted earlier, this API uses API keys for authentication. You can generate a Segnivo API key in the [API](https://messaging.segnivo.com/account/api) section of your account settings.  You must include an API key in each request to this API with the `X-API-KEY` request header.  ### Authentication error response  If an API key is missing, malformed, or invalid, you will receive an HTTP 401 Unauthorized response code.  ## Rate and usage limits  API access rate limits apply on a per-API endpoint basis in unit time. The limit is 10k requests per hour for most endpoints and 1m requests per hour for transactional/relay email-sending endpoints. Also, depending on your plan, you may have usage limits. If you exceed either limit, your request will return an HTTP 429 Too Many Requests status code or HTTP 403 if sending credits have been exhausted.  ### 503 response  An HTTP `503` response from our servers may indicate there is an unexpected spike in API access traffic, while this rarely happens, we ensure the server is usually operational within the next two to five minutes. If the outage persists or you receive any other form of an HTTP `5XX` error, contact support ([<i>developers@segnivo.com</i>](https://mailto:developers@segnivo.com)).  ### Request headers  To make a successful request, some or all of the following headers must be passed with the request.  | **Header** | **Description** | | --- | --- | | Content-Type | Required and should be `application/json` in most cases. | | Accept | Required and should be `application/json` in most cases | | Content-Length | Required for `POST`, `PATCH`, and `PUT` requests containing a request body. The value must be the number of bytes rather than the number of characters in the request body. | | X-API-KEY | Required. Specifies the API key used for authorization. |  ##### 🔖 Note with example requests and code snippets  If/when you use the code snippets used as example requests, remember to calculate and add the `Content-Length` header. Some request libraries, frameworks, and tools automatically add this header for you while a few do not. Kindly check and ensure yours does or add it yourself.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class RelayEmailRequest(BaseModel):
    """
    RelayEmailRequest
    """ # noqa: E501
    subject: Optional[StrictStr] = Field(default=None, description="The subject of the email")
    from_name: Optional[StrictStr] = Field(default=None, description="The full name of the sender")
    from_email: Optional[StrictStr] = Field(default=None, description="The email of the sender")
    reply_to: Optional[StrictStr] = Field(default=None, description="The email to which replies should be sent")
    content_type: Optional[StrictStr] = Field(default='html', description="The content type of the email body")
    recipients: Optional[Annotated[List[StrictStr], Field(max_length=50)]] = Field(default=None, description="An array of email addresses to deliver this message")
    content: Optional[StrictStr] = Field(default=None, description="The HTML or plain text content of the email")
    preheader: Optional[StrictStr] = Field(default=None, description="The email preheader")
    custom_headers: Optional[Dict[str, Any]] = Field(default=None, description="An object of custom headers to add to the email")
    delivery_at: Optional[StrictInt] = Field(default=None, description="The 10-digit unix timestamp of the date/time at which this email should be delivered")
    attachments: Optional[List[StrictStr]] = Field(default=None, description="An array of URLs of files to attach to the email")
    sign_dkim: Optional[StrictBool] = Field(default=True, description="A boolean value on if a DKIM signature should be included in this message")
    track_click: Optional[StrictBool] = Field(default=True, description="A boolean value on if email clicks should be tracked")
    track_open: Optional[StrictBool] = Field(default=True, description="A boolean value on if the email opens should be tracked")
    is_transactional: Optional[StrictBool] = Field(default=False, description="A boolean value to flag this email as a transactional email")
    __properties: ClassVar[List[str]] = ["subject", "from_name", "from_email", "reply_to", "content_type", "recipients", "content", "preheader", "custom_headers", "delivery_at", "attachments", "sign_dkim", "track_click", "track_open", "is_transactional"]

    @field_validator('content_type')
    def content_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['text', 'html']):
            raise ValueError("must be one of enum values ('text', 'html')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RelayEmailRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RelayEmailRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "subject": obj.get("subject"),
            "from_name": obj.get("from_name"),
            "from_email": obj.get("from_email"),
            "reply_to": obj.get("reply_to"),
            "content_type": obj.get("content_type") if obj.get("content_type") is not None else 'html',
            "recipients": obj.get("recipients"),
            "content": obj.get("content"),
            "preheader": obj.get("preheader"),
            "custom_headers": obj.get("custom_headers"),
            "delivery_at": obj.get("delivery_at"),
            "attachments": obj.get("attachments"),
            "sign_dkim": obj.get("sign_dkim") if obj.get("sign_dkim") is not None else True,
            "track_click": obj.get("track_click") if obj.get("track_click") is not None else True,
            "track_open": obj.get("track_open") if obj.get("track_open") is not None else True,
            "is_transactional": obj.get("is_transactional") if obj.get("is_transactional") is not None else False
        })
        return _obj


